/******************** (C) COPYRIGHT 2011 STMicroelectronics ********************
* File Name          : usb_desc.c
* Author             : MCD Application Team
* Version            : V3.3.0
* Date               : 21-March-2011
* Description        : Descriptors for Virtual Com Port Demo
********************************************************************************
* THE PRESENT FIRMWARE WHICH IS FOR GUIDANCE ONLY AIMS AT PROVIDING CUSTOMERS
* WITH CODING INFORMATION REGARDING THEIR PRODUCTS IN ORDER FOR THEM TO SAVE TIME.
* AS A RESULT, STMICROELECTRONICS SHALL NOT BE HELD LIABLE FOR ANY DIRECT,
* INDIRECT OR CONSEQUENTIAL DAMAGES WITH RESPECT TO ANY CLAIMS ARISING FROM THE
* CONTENT OF SUCH FIRMWARE AND/OR THE USE MADE BY CUSTOMERS OF THE CODING
* INFORMATION CONTAINED HEREIN IN CONNECTION WITH THEIR PRODUCTS.
*******************************************************************************/

/* Includes ------------------------------------------------------------------*/
#include "usb_lib.h"
#include "usb_desc.h"

/* USB Standard Device Descriptor */
const uint8_t JUPOD_DeviceDescriptor[JUPOD_SIZ_DEVICE_DESC] =
  {
    0x12,                       /*bLength */
    USB_DEVICE_DESCRIPTOR_TYPE, /*bDescriptorType*/
    0x00,                       /*USB 2.0 */
    0x02,
    0xFF,                       /*bDeviceClass*/
    0x00,                       /*bDeviceSubClass*/
    0x00,                       /*bDeviceProtocol*/
    0x40,                       /*bMaxPacketSize 64*/
    0x88,                       /*idVendor (0x8888)*/
    0x88,
    0x19,                       /*idProduct = 0x0519*/
    0x05,
    0x00,                       /*rel. 1.00*/
    0x01,
    1,                          /*Index of string descriptor describing manufacturer */
    2,                          /*Index of string descriptor describing product*/
    3,                          /*Index of string descriptor describing the device serial number */
    0x01                        /*bNumConfigurations*/
  }
  ; /* JUPOD_DeviceDescriptor */


const uint8_t JUPOD_ConfigDescriptor[JUPOD_SIZ_CONFIG_DESC] =
  {
    0x09, /* bLength: Configuration Descriptor size */
    USB_CONFIGURATION_DESCRIPTOR_TYPE, /* bDescriptorType: Configuration */
    JUPOD_SIZ_CONFIG_DESC&0xFF,/* wTotalLength: Bytes returned */
    (JUPOD_SIZ_CONFIG_DESC>>8)&0xFF,
    0x01,         /*bNumInterfaces: 1 interface*/
    0x01,         /*bConfigurationValue: Configuration value*/
    0x00,         /*iConfiguration: Index of string descriptor describing
                                     the configuration*/
    0x80,         /*bmAttributes: bus powered ҲԶ̻*/
    0x32,         /*MaxPower 100 mA: this current is used for detecting Vbus*/

    /************** Descriptor of JUPOD interface ****************/
    /* 09 */
    0x09,         /*bLength: Interface Descriptor size*/
    USB_INTERFACE_DESCRIPTOR_TYPE,/*bDescriptorType: Interface descriptor type*/
    0x00,         /*bInterfaceNumber: Number of Interface*/
    0x00,         /*bAlternateSetting: Alternate settingýӿں*/
    0x02,         /*bNumEndpoints*/
    0x00,         /*bInterfaceClass: */
    0x00,         /*bInterfaceSubClass : */
    0x00,         /*nInterfaceProtocol : */
    0x00,         /*iInterface: Index of string descriptorýӿڵֵַûУΪ0*/
    /******************** Descriptor of JUPOD endpoint ********************/
	/* 18 */
	0x07,          /*bLength: Endpoint Descriptor size*/
    USB_ENDPOINT_DESCRIPTOR_TYPE, /*bDescriptorType:*/
    0x82,          /*bEndpointAddress: Endpoint Address (IN)*/
    0x02,          /*bmAttributes: BULK*/
    JUPOD_DATA_SIZE,          /*wMaxPacketSize: 64 Byte max */
    0x00,
    0x00,          /*bInterval:*/
	/* 25 */
	0x07,          /*bLength: Endpoint Descriptor size*/
    USB_ENDPOINT_DESCRIPTOR_TYPE, /*bDescriptorType:*/
    0x03,          /*bEndpointAddress: Endpoint Address (OUT)*/
    0x02,          /*bmAttributes: BULK*/
    JUPOD_DATA_SIZE,          /*wMaxPacketSize: 64 Byte max */
    0x00,
    0x00,          /*bInterval:*/
	/* 32 */
  }
  ; /* ConfigDescriptor */

/* USB String Descriptors */
const uint8_t JUPOD_StringLangID[JUPOD_SIZ_STRING_LANGID] =
  {
    JUPOD_SIZ_STRING_LANGID,
    USB_STRING_DESCRIPTOR_TYPE,
    0x09,
    0x04
  }
  ; /* LangID = 0x0409: U.S. English */

const uint8_t JUPOD_StringVendor[JUPOD_SIZ_STRING_VENDOR] =
  {
    JUPOD_SIZ_STRING_VENDOR,     /* Size of Vendor string */
    USB_STRING_DESCRIPTOR_TYPE,             /* bDescriptorType*/
    /* Manufacturer: "STMicroelectronics" */
    'S', 0, 'T', 0, 'M', 0, 'i', 0, 'c', 0, 'r', 0, 'o', 0, 'e', 0,
    'l', 0, 'e', 0, 'c', 0, 't', 0, 'r', 0, 'o', 0, 'n', 0, 'i', 0,
    'c', 0, 's', 0,
  };

const uint8_t JUPOD_StringProduct[JUPOD_SIZ_STRING_PRODUCT] =
  {
    JUPOD_SIZ_STRING_PRODUCT,          /* bLength */
    USB_STRING_DESCRIPTOR_TYPE,        /* bDescriptorType */
    'J', 0,	'T', 0, 'A', 0, 'G', 0, ' ', 0, 'A', 0, 'd', 0, 'a', 0,	 
    'p', 0, 't', 0, 'e', 0, 'r', 0
  };

uint8_t JUPOD_StringSerial[JUPOD_SIZ_STRING_SERIAL] =
  {
    JUPOD_SIZ_STRING_SERIAL,           /* bLength */
    USB_STRING_DESCRIPTOR_TYPE,                   /* bDescriptorType */
    'S', 0, 'T', 0, 'M', 0, '3', 0, '2', 0, 'F', 0, '1', 0, '0', 0,  
	'3', 0, 'C', 0, '8', 0, 'T', 0, '6', 0
  };

/******************* (C) COPYRIGHT 2011 STMicroelectronics *****END OF FILE****/
